==> jtools-nodejs-1.2.15.tgz: package/ChaveSeguranca.js <==
"use strict";
var DiaHora = require("./DiaHora");
var Texto = require("./Texto");
var ChaveSeguranca = /** @class */ (function () {
    function ChaveSeguranca(data, login, contrasenha, encriptacao) {
        this.data = data;
        this.login = login;
        this.contrasenha = contrasenha;
        this.encriptacao = encriptacao;
    }
    ChaveSeguranca.prototype.geraDigest = function () {
        this.login = this.login || '';
        this.contrasenha = this.contrasenha || '';
        //...
        var _num1 = this.data.anoFormatado;
        var _num2 = this.data.mesFormatado + this.data.minutoFormatado;
        var _num3 = this.data.diaFormatado + this.data.segundoFormatado;
        var _num4 = this.data.horaFormatada;
        //======
        var _retorno = "" + _num1 + this.login + _num2 + _num3 + this.contrasenha + _num4;
        if (this.encriptacao)
            _retorno = this.encriptacao(_retorno);
        return _retorno;
    };
    ChaveSeguranca.prototype.geraToken = function () {
        return this.login + "<#>" + this.data.compacta() + "<#>" + this.geraDigest();
    };
    ChaveSeguranca.desmembra = function (token) {
        token = Texto.limpa(token);
        var _partes = token.split('<#>');
        if (_partes.length != 3)
            throw new Error('[0] Chave de segurança incorrreta');
        return {
            login: _partes[0],
            data: DiaHora.descompacta(_partes[1]),
            digest: _partes[2]
        };
    };
    return ChaveSeguranca;
}());
module.exports = ChaveSeguranca;

==> jtools-nodejs-1.4.0.tgz: package/ChaveSeguranca.js <==
var DiaHora = require('./DiaHora');
var Texto = require('./Texto');

var ChaveSeguranca = (function () {
    function ChaveSeguranca(data, login, contrasenha, encriptacao) {
        this.data = data;
        this.login = login;
        this.contrasenha = contrasenha;
        this.encriptacao = encriptacao;
    }
    ChaveSeguranca.prototype.geraDigest = function () {
        this.login = this.login || '';
        this.contrasenha = this.contrasenha || '';

        //...
        var _num1 = this.data.anoFormatado;
        var _num2 = this.data.mesFormatado + this.data.minutoFormatado;
        var _num3 = this.data.diaFormatado + this.data.segundoFormatado;
        var _num4 = this.data.horaFormatada;

        //======
        var _retorno = _num1 + this.login + _num2 + _num3 + this.contrasenha + _num4;
        if (this.encriptacao)
            _retorno = this.encriptacao(_retorno);
        return _retorno;
    };
    ChaveSeguranca.prototype.geraToken = function () {
        return this.login + '!;;!' + this.data.compacta() + '!;;!' + this.geraDigest();
    };
    ChaveSeguranca.desmembra = function (token) {
        token = Texto.limpa(token);
        var _partes = token.split('!;;!');
        if (_partes.length != 3)
            throw new Error('[0] Chave de segurança incorrreta');
        return {
            login: _partes[0],
            data: DiaHora.descompacta(_partes[1]),
            digest: _partes[2]
        };
    };
    return ChaveSeguranca;
})();

module.exports = ChaveSeguranca;
